==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/pt-BR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirma a exclusão de Ativos em Massa',
    'bulk_restore'      => 'Confirmar Restauração de Ativos em Massa', 
  'bulk_delete_help'	=> 'Reveja os ativos selecionados para deletar. Depois de deletados, estes ativos podem ser restaurados, mas não estarão associados aos usuários.',
  'bulk_restore_help'	=> 'Revise os ativos para restauração em massa abaixo. Uma vez restaurados, estes ativos não serão associados a quaisquer usuários aos quais foram atribuídos anteriormente.',
  'bulk_delete_warn'	=> 'Você está prestes a excluir.',
  'bulk_restore_warn'	=> 'Você está prestes a restaurar :asset_count ativos.',
    'bulk_update'		=> 'Ativos da Atualização em Massa',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez só. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado. ',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de um único ativo.Você está prestes a editar as propriedades de :asset_count ativos.',
    'bulk_update_with_custom_field' => 'Observe que os ativos são :asset_model_count diferentes tipos de modelos.',
    'bulk_update_model_prefix' => 'Em Modelos', 
    'bulk_update_custom_field_unique' => 'Este é um campo único e não pode ser editado em massa.',
    'checkedout_to'		=> 'Alocado para',
    'checkout_date'		=> 'Data de alocação',
    'checkin_date'		=> 'Data de devolução',
    'checkout_to'		=> 'Alocado para',
    'cost'				=> 'Custo da Compra',
    'create'			=> 'Criar Ativo',
    'date'				=> 'Data da Compra',
    'depreciation'	    => 'Depreciação',
    'depreciates_on'	=> 'Deprecia em',
    'default_location'	=> 'Local Padrão',
    'default_location_phone' => 'Telefone de localização padrão',
    'eol_date'			=> 'Date de EOL',
    'eol_rate'			=> 'Classificação de EOL',
    'expected_checkin'  => 'Excedeu a data dar entrada',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Se você quiser designar este ativo imediatamente, selecione "Pronto para Entregar" a partir da lista de situações acima. ',
    'mac_address'		=> 'Endereço MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nome do Ativo',
    'notes'				=> 'Notas',
    'order'				=> 'Número do Pedido',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Usuários podem solicitar este ativo',
    'redirect_to_all'   => 'Voltar para todos os :type',
    'redirect_to_type'   => 'Ir para :type',
    'redirect_to_checked_out_to'   => 'Ir para Checked Out para',
    'select_statustype'	=> 'Selecione o Tipo de Situação',
    'serial'			=> 'Serial',
    'status'			=> 'Situação',
    'tag'				=> 'Marcação do Ativo',
    'update'			=> 'Atualização do Ativo',
    'warranty'			=> 'Garantia',
        'warranty_expires'		=> 'A garantia expira',
    'years'				=> 'anos',
    'asset_location' => 'Atualizar Local do Ativo',
    'asset_location_update_default_current' => 'Atualizar a localização padrão e local real',
    'asset_location_update_default' => 'Atualizar somente local padrão',
    'asset_location_update_actual' => 'Atualizar somente a localização atual',
    'asset_not_deployable' => 'Esta situação de ativo não é implementável. A saída deste ativo não pode ser realizada.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Esta situação pode ser implementado. A saída deste ativo pode ser realizada.',
    'processing_spinner' => 'Processando... (Isso pode levar algum tempo em arquivos grandes)',
    'optional_infos'  => 'Informação Opcional',
    'order_details'   => 'Informações do pedido relacionado'
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pt-BR/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirma a exclusão de Ativos em Massa',
    'bulk_restore'      => 'Confirmar Restauração de Ativos em Massa', 
  'bulk_delete_help'	=> 'Reveja os ativos selecionados para deletar. Depois de deletados, estes ativos podem ser restaurados, mas não estarão associados aos usuários.',
  'bulk_restore_help'	=> 'Revise os ativos para restauração em massa abaixo. Uma vez restaurados, estes ativos não serão associados a quaisquer usuários aos quais foram atribuídos anteriormente.',
  'bulk_delete_warn'	=> 'Você está prestes a excluir.',
  'bulk_restore_warn'	=> 'Você está prestes a restaurar :asset_count ativos.',
    'bulk_update'		=> 'Ativos da Atualização em Massa',
    'bulk_update_help'	=> 'Este formulário lhe permite atualizar múltiplos ativos de uma vez só. Apenas preencha os campos que você precisa alterar. Qualquer campo deixado em branco permanecerá inalterado. ',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de um único ativo.Você está prestes a editar as propriedades de :asset_count ativos.',
    'bulk_update_with_custom_field' => 'Observe que os ativos são :asset_model_count diferentes tipos de modelos.',
    'bulk_update_model_prefix' => 'Em Modelos', 
    'bulk_update_custom_field_unique' => 'Este é um campo único e não pode ser editado em massa.',
    'checkedout_to'		=> 'Alocado para',
    'checkout_date'		=> 'Data de alocação',
    'checkin_date'		=> 'Data de devolução',
    'checkout_to'		=> 'Alocado para',
    'cost'				=> 'Custo da Compra',
    'create'			=> 'Criar Ativo',
    'date'				=> 'Data da Compra',
    'depreciation'	    => 'Depreciação',
    'depreciates_on'	=> 'Deprecia em',
    'default_location'	=> 'Local Padrão',
    'default_location_phone' => 'Telefone de localização padrão',
    'eol_date'			=> 'Date de EOL',
    'eol_rate'			=> 'Classificação de EOL',
    'expected_checkin'  => 'Excedeu a data dar entrada',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Se você quiser designar este ativo imediatamente, selecione "Pronto para Entregar" a partir da lista de situações acima. ',
    'mac_address'		=> 'Endereço MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nome do Ativo',
    'notes'				=> 'Notas',
    'order'				=> 'Número do Pedido',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Usuários podem solicitar este ativo',
    'redirect_to_all'   => 'Voltar para todos os :type',
    'redirect_to_type'   => 'Ir para :type',
    'redirect_to_checked_out_to'   => 'Ir para Checked Out para',
    'select_statustype'	=> 'Selecione o Tipo de Situação',
    'serial'			=> 'Serial',
    'status'			=> 'Situação',
    'tag'				=> 'Marcação do Ativo',
    'update'			=> 'Atualização do Ativo',
    'warranty'			=> 'Garantia',
        'warranty_expires'		=> 'A garantia expira',
    'years'				=> 'anos',
    'asset_location' => 'Atualizar Local do Ativo',
    'asset_location_update_default_current' => 'Atualizar a localização padrão e local real',
    'asset_location_update_default' => 'Atualizar somente local padrão',
    'asset_location_update_actual' => 'Atualizar somente a localização atual',
    'asset_not_deployable' => 'Esta situação de ativo não é implementável. A saída deste ativo não pode ser realizada.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Esta situação pode ser implementado. A saída deste ativo pode ser realizada.',
    'processing_spinner' => 'Processando... (Isso pode levar algum tempo em arquivos grandes)',
    'optional_infos'  => 'Informação Opcional',
    'order_details'   => 'Informações do pedido relacionado',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
